==> aiida-optimize-0.1.1.tar.gz: aiida-optimize-0.1.1/aiida_optimize/engines/_parameter_sweep.py <==
# -*- coding: utf-8 -*-

# © 2017-2019, ETH Zurich, Institut für Theoretische Physik
# Author: Dominik Gresch <greschd@gmx.ch>
"""
Defines a parameter sweep optimization engine.
"""

from __future__ import division, print_function, unicode_literals

from fsc.export import export

from aiida.orm.data import to_aiida_type

from ._base import OptimizationEngineWrapper, OptimizationEngineImpl


class _ParameterSweepImpl(OptimizationEngineImpl):
    """
    Implementation class for the parameter sweep engine.
    """

    def __init__(self, parameters, result_key, logger, result_state=None):
        super(_ParameterSweepImpl, self).__init__(logger=logger, result_state=result_state)
        self._parameters = parameters
        self._result_key = result_key

    @property
    def _state(self):
        return {'parameters': self._parameters, 'result_key': self._result_key}

    @property
    def is_finished(self):
        if len(self._result_mapping) < len(self._parameters):
            return False
        return not any(res.output is None for res in self._result_mapping.values())

    def _create_inputs(self):
        return [{k: to_aiida_type(v)
                 for k, v in param_dict.items()} for param_dict in self._parameters]

    def _update(self, outputs):
        pass

    @property
    def result_value(self):
        _, value = self._get_optimal_result()
        return value

    @property
    def result_index(self):
        index, _ = self._get_optimal_result()
        return index

    def _get_optimal_result(self):
        """
        Return the index and optimizatin value of the best calculation workflow.
        """
        cost_values = {k: v.output[self._result_key] for k, v in self._result_mapping.items()}
        return min(cost_values.items(), key=lambda item: item[1].value)


@export
class ParameterSweep(OptimizationEngineWrapper):
    """
    Optimization engine that performs a parameter sweep.

    :param parameters: List of parameter dictionaries. For each entry, a calculation with the given parameters will be run.
    :type parameters: list(dict)

    :param result_key: Name of the calculation workchain output argument.
    :type result_key: str
    """
    _IMPL_CLASS = _ParameterSweepImpl

    def __new__(cls, parameters, result_key='result', logger=None):  # pylint: disable=arguments-differ
        return cls._IMPL_CLASS(parameters=parameters, result_key=result_key, logger=logger)

==> aiida-optimize-0.2.0.tar.gz: aiida-optimize-0.2.0/aiida_optimize/engines/_parameter_sweep.py <==
# -*- coding: utf-8 -*-

# © 2017-2019, ETH Zurich, Institut für Theoretische Physik
# Author: Dominik Gresch <greschd@gmx.ch>
"""
Defines a parameter sweep optimization engine.
"""

from __future__ import division, print_function, unicode_literals

from fsc.export import export

from aiida.orm.nodes.data.base import to_aiida_type

from ._base import OptimizationEngineWrapper, OptimizationEngineImpl


class _ParameterSweepImpl(OptimizationEngineImpl):
    """
    Implementation class for the parameter sweep engine.
    """
    def __init__(self, parameters, result_key, logger, result_state=None):
        super(_ParameterSweepImpl, self).__init__(logger=logger, result_state=result_state)
        self._parameters = parameters
        self._result_key = result_key

    @property
    def _state(self):
        return {'parameters': self._parameters, 'result_key': self._result_key}

    @property
    def is_finished(self):
        if len(self._result_mapping) < len(self._parameters):
            return False
        return not any(res.output is None for res in self._result_mapping.values())

    def _create_inputs(self):
        return [{k: to_aiida_type(v)
                 for k, v in param_dict.items()} for param_dict in self._parameters]

    def _update(self, outputs):
        pass

    @property
    def result_value(self):
        _, value = self._get_optimal_result()
        return value

    @property
    def result_index(self):
        index, _ = self._get_optimal_result()
        return index

    def _get_optimal_result(self):
        """
        Return the index and optimizatin value of the best calculation workflow.
        """
        cost_values = {k: v.output[self._result_key] for k, v in self._result_mapping.items()}
        return min(cost_values.items(), key=lambda item: item[1].value)


@export
class ParameterSweep(OptimizationEngineWrapper):
    """
    Optimization engine that performs a parameter sweep.

    :param parameters: List of parameter dictionaries. For each entry, a calculation with the given parameters will be run.
    :type parameters: list(dict)

    :param result_key: Name of the calculation workchain output argument.
    :type result_key: str
    """
    _IMPL_CLASS = _ParameterSweepImpl

    def __new__(cls, parameters, result_key='result', logger=None):  # pylint: disable=arguments-differ
        return cls._IMPL_CLASS(parameters=parameters, result_key=result_key, logger=logger)
